@@ -1,6 +1,7 @@
 # Copyright 2013 - Mirantis, Inc.
 # Copyright 2016 - Brocade Communications Systems, Inc.
 # Copyright 2018 - Extreme Networks, Inc.
+# Copyright 2019 - Nokia Networks
 #
 #    Licensed under the Apache License, Version 2.0 (the "License");
 #    you may not use this file except in compliance with the License.
@@ -86,6 +87,17 @@ api_opts = [
         help=_('Number of workers for Mistral API service '
                'default is equal to the number of CPUs available if that can '
                'be determined, else a default worker count of 1 is returned.')
+    ),
+    cfg.StrOpt(
+        'validation_mode',
+        default='mandatory',
+        choices=['enabled', 'mandatory', 'disabled'],
+        help=_("Defines in what cases Mistral will be validating the syntax "
+               "of workflow YAML definitions. If 'enabled' is set the service "
+               "will be validating the syntax but only if it's not explicitly "
+               "turned off in the API request. 'disabled' disables validation "
+               "for all API requests. 'mandatory' enables validation for all "
+               "API requests.")
     )
 ]
 
@@ -197,6 +209,16 @@ engine_opts = [
         default=60,
         help=_('A number of seconds that indicates how long action '
                'definitions should be stored in the local cache.')
+    ),
+    cfg.BoolOpt(
+        'start_subworkflows_via_rpc',
+        default=False,
+        help=(
+            'Enables starting subworkflows via RPC. Use "False" to start '
+            'subworkflow within the same engine instance. Use "True" '
+            'to start subworkflow via RPC to improve load balancing '
+            'in case of several engine instances.'
+        )
     )
 ]
 
@@ -214,9 +236,13 @@ executor_opts = [
     cfg.HostAddressOpt(
         'host',
         default='0.0.0.0',
-        help=_('Name of the executor node. This can be an opaque '
-               'identifier. It is not necessarily a hostname, '
-               'FQDN, or IP address.')
+        help=_('Name of the executor node. This can be an any string '
+               'name/identifier. It is not necessarily a hostname, '
+               'FQDN, or IP address. It is also related to the "target" '
+               'attribute of tasks defined in a workflow text. If "target" '
+               'is defined for a task then the action of the task will be '
+               'sent to one of the executors that have the same value in the '
+               '"host" property.')
     ),
     cfg.StrOpt(
         'topic',
@@ -230,6 +256,13 @@ executor_opts = [
     )
 ]
 
+scheduler_type_opt = cfg.StrOpt(
+    'scheduler_type',
+    default='legacy',
+    choices=['legacy', 'default'],
+    help=_('The name of the scheduler implementation used in the system.')
+)
+
 scheduler_opts = [
     cfg.FloatOpt(
         'fixed_delay',
@@ -564,7 +597,7 @@ yaql_opts = [
         'convert_input_data',
         default=True,
         help=_('Enables input data conversion for YAQL expressions. If set '
-               'to True then YAQL will convert mutable data structures '
+               'to True, YAQL will convert mutable data structures '
                '(lists, dicts, sets) into their immutable versions. That '
                'will allow them to work with some constructs that require '
                'hashable types even if elements are not hashable. For '
@@ -577,23 +610,38 @@ yaql_opts = [
                'performance boost if the input data for an expression is '
                'large.')
     ),
+    cfg.BoolOpt(
+        'convert_output_data',
+        default=True,
+        help=_('Enables output data conversion for YAQL expressions.'
+               'If set to False, it is possible that YAQL will generate '
+               'an output that will be not JSON-serializable. For example, '
+               'if an expression has ".toSet()" in the end to convert a list '
+               'into a set. It does not mean though that such functions '
+               'cannot be used, they can still be used in expressions but '
+               'user has to keep in mind of what type a result will be, '
+               'whereas if the value of ths property is True YAQL will '
+               'convert the result to a JSON-compatible type.')
+    ),
     cfg.BoolOpt(
         'convert_tuples_to_lists',
         default=True,
-        help=_('When set to true, yaql converts all tuples in the expression '
-               'result to lists.')
+        help=_('When set to True, yaql converts all tuples in the expression '
+               'result to lists. It works only if "convert_output_data" is '
+               'set to True.')
     ),
     cfg.BoolOpt(
         'convert_sets_to_lists',
         default=False,
-        help=_('When set to true, yaql converts all sets in the expression '
+        help=_('When set to True, yaql converts all sets in the expression '
                'result to lists. Otherwise the produced result may contain '
-               'sets that are not JSON-serializable.')
+               'sets that are not JSON-serializable. It works only if '
+               '"convert_output_data" is set to True.')
     ),
     cfg.BoolOpt(
         'iterable_dicts',
         default=False,
-        help=_('When set to true, dictionaries are considered to be iterable '
+        help=_('When set to True, dictionaries are considered to be iterable '
                'and iteration over dictionaries produces their keys (as in '
                'Python and yaql 0.2).')
     ),
@@ -633,6 +681,7 @@ KEYSTONE_GROUP = "keystone"
 
 CONF.register_opt(wf_trace_log_name_opt)
 CONF.register_opt(auth_type_opt)
+CONF.register_opt(scheduler_type_opt)
 CONF.register_opt(js_impl_opt)
 CONF.register_opt(rpc_impl_opt)
 CONF.register_opt(rpc_response_timeout_opt)
@@ -672,6 +721,7 @@ default_group_opts = itertools.chain(
     [
         wf_trace_log_name_opt,
         auth_type_opt,
+        scheduler_type_opt,
         js_impl_opt,
         rpc_impl_opt,
         rpc_response_timeout_opt,
@@ -680,8 +730,6 @@ default_group_opts = itertools.chain(
     ]
 )
 
-CONF.register_cli_opts(CLI_OPTS)
-
 
 _DEFAULT_LOG_LEVELS = [
     'eventlet.wsgi.server=WARN',
