@@ -1,4 +1,5 @@
 # Copyright 2015 - Mirantis, Inc.
+# Copyright 2020 - Nokia Software.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License");
 #    you may not use this file except in compliance with the License.
@@ -13,10 +14,10 @@
 #    limitations under the License.
 
 import abc
-import json
 
 from mistral import config as cfg
 from mistral import exceptions as exc
+from mistral import utils
 
 from oslo_utils import importutils
 from stevedore import driver
@@ -46,44 +47,52 @@ class JSEvaluator(object):
 
 class PyV8Evaluator(JSEvaluator):
     @classmethod
-    def evaluate(cls, script, context):
+    def evaluate(cls, script, ctx):
         if not _PYV8:
             raise exc.MistralException(
                 "PyV8 module is not available. Please install PyV8."
             )
 
-        with _PYV8.JSContext() as ctx:
+        with _PYV8.JSContext() as js_ctx:
             # Prepare data context and way for interaction with it.
-            ctx.eval('$ = %s' % json.dumps(context))
+            js_ctx.eval('$ = %s' % utils.to_json_str(ctx))
+
+            result = js_ctx.eval(script)
 
-            result = ctx.eval(script)
             return _PYV8.convert(result)
 
 
 class V8EvalEvaluator(JSEvaluator):
     @classmethod
-    def evaluate(cls, script, context):
+    def evaluate(cls, script, ctx):
         if not _V8EVAL:
             raise exc.MistralException(
                 "v8eval module is not available. Please install v8eval."
             )
 
         v8 = _V8EVAL.V8()
-        return v8.eval(('$ = %s; %s' % (json.dumps(context), script)).encode(
-            encoding='UTF-8'))
+
+        ctx_str = utils.to_json_str(ctx)
+
+        return v8.eval(
+            ('$ = %s; %s' % (ctx_str, script)).encode(encoding='UTF-8')
+        )
 
 
 class PyMiniRacerEvaluator(JSEvaluator):
     @classmethod
-    def evaluate(cls, script, context):
+    def evaluate(cls, script, ctx):
         if not _PY_MINI_RACER:
             raise exc.MistralException(
                 "PyMiniRacer module is not available. Please install "
                 "PyMiniRacer."
             )
 
-        ctx = _PY_MINI_RACER.MiniRacer()
-        return ctx.eval(('$ = {}; {}'.format(json.dumps(context), script)))
+        js_ctx = _PY_MINI_RACER.MiniRacer()
+
+        return js_ctx.eval(
+            '$ = {}; {}'.format(utils.to_json_str(ctx), script)
+        )
 
 
 _mgr = extension.ExtensionManager(
@@ -107,5 +116,5 @@ def get_js_evaluator():
     return _EVALUATOR
 
 
-def evaluate(script, context):
-    return get_js_evaluator().evaluate(script, context)
+def evaluate(script, ctx):
+    return get_js_evaluator().evaluate(script, ctx)
