@@ -1,4 +1,5 @@
 # Copyright 2015 - Mirantis, Inc.
+# Copyright 2020 - NetCracker Technology Corp.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License");
 #    you may not use this file except in compliance with the License.
@@ -76,7 +77,7 @@ class DirectWorkflowController(base.WorkflowController):
             task_ex
         )
 
-        # Checking if task_ex is empty here is a serious optimization here
+        # Checking if task_ex is empty is a serious optimization here
         # because 'self.wf_ex.task_executions' leads to initialization of
         # the entire collection which in case of highly-parallel workflows
         # may be very expensive.
@@ -107,6 +108,10 @@ class DirectWorkflowController(base.WorkflowController):
             for t_s in self.wf_spec.find_start_tasks()
         ]
 
+    @profiler.trace(
+        'direct-wf-controller-find-next-commands-for-task',
+        hide_args=True
+    )
     def _find_next_commands_for_task(self, task_ex):
         """Finds next commands based on the state of the given task.
 
@@ -220,9 +225,8 @@ class DirectWorkflowController(base.WorkflowController):
             if not self.wf_spec.get_tasks()[t_name]:
                 continue
 
-            if t_name in all_joins:
-                if t_name in t_execs_cache:
-                    res.add(t_execs_cache[t_name])
+            if t_name in all_joins and t_name in t_execs_cache:
+                res.add(t_execs_cache[t_name])
                 continue
 
             clauses.update(self.wf_spec.find_outbound_task_names(t_name))
